@@ -23,16 +23,21 @@ struct _GIOPThread {
 	GCond        *incoming;
 	GMainContext *wake_context;
 
-	gpointer      key;	/* ie. per POA, per Connection etc. */
+	GList        *keys;	/* ie. per POA, per Connection, per Object etc. */
+
+	GList        *async_ents;
+	GList        *request_queue;
+
+	GQueue       *invoke_policies;
 
-	GQueue       *async_ents;
-	GQueue       *request_queue;
 	void        (*request_handler) (gpointer poa_object,
 					gpointer recv_buffer,
 					gpointer dummy);
 };
 
-#define GIOP_INITIAL_MSG_SIZE_LIMIT 256*1024
+#define GIOP_INITIAL_TIMEOUT_LIMIT (30000000) /* 30 seconds */
+
+#define GIOP_INITIAL_MSG_SIZE_LIMIT (256*1024) /* in bytes */
 
 typedef enum {
 	GIOP_CONNECTION_SSL
