@@ -2,16 +2,17 @@
 #define __ORBIT_DEBUG_H__
 
 typedef enum {
-	ORBIT_DEBUG_NONE          = 0,
-	ORBIT_DEBUG_TRACES        = 1 << 0,
-	ORBIT_DEBUG_INPROC_TRACES = 1 << 1,
-	ORBIT_DEBUG_TIMINGS       = 1 << 2,
-	ORBIT_DEBUG_TYPES         = 1 << 3,
-	ORBIT_DEBUG_MESSAGES      = 1 << 4,
-	ORBIT_DEBUG_ERRORS        = 1 << 5,
-	ORBIT_DEBUG_OBJECTS       = 1 << 6,
-	ORBIT_DEBUG_GIOP          = 1 << 7,
-	ORBIT_DEBUG_REFS          = 1 << 8
+	ORBIT_DEBUG_NONE           = 0,
+	ORBIT_DEBUG_TRACES         = 1 << 0,
+	ORBIT_DEBUG_INPROC_TRACES  = 1 << 1,
+	ORBIT_DEBUG_TIMINGS        = 1 << 2,
+	ORBIT_DEBUG_TYPES          = 1 << 3,
+	ORBIT_DEBUG_MESSAGES       = 1 << 4,
+	ORBIT_DEBUG_ERRORS         = 1 << 5,
+	ORBIT_DEBUG_OBJECTS        = 1 << 6,
+	ORBIT_DEBUG_GIOP           = 1 << 7,
+	ORBIT_DEBUG_REFS           = 1 << 8,
+	ORBIT_DEBUG_FORCE_THREADED = 1 << 9
 } OrbitDebugFlags;
 
 #ifndef G_ENABLE_DEBUG
@@ -24,10 +25,12 @@ typedef enum {
 #  define dprintf(args...)
 #  define tprintf(args...)
 #else
+/* This sucks for compatibility - fix your compiler */
 #define MESSAGES (OrbitDebugFlags)0
-#define TYPES (OrbitDebugFlags)0
-#define OBJECTS (OrbitDebugFlags)0
-#define GIOP (OrbitDebugFlags)0
+#define TYPES    (OrbitDebugFlags)0
+#define OBJECTS  (OrbitDebugFlags)0
+#define GIOP     (OrbitDebugFlags)0
+#define ERRORS   (OrbitDebugFlags)0
 static inline void dprintf (OrbitDebugFlags flags, const char *format, ...)
 {
 }
